@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2021-02-10
+# Release 2021-03-30
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.4.5
+MAKERESOLVEDEB_VERSION=1.4.6
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -314,10 +314,7 @@ process17() {
     copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
-    if ! [[ "$RESOLVE_VERSION" == 16.0b* ]];
-    then
-	copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
-    fi
+    copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/scripts/script.checkfirmware ${RESOLVE_BASE_DIR}/scripts/
     copy_object ${UNPACK_DIR}/scripts/script.getlogs.v4 ${RESOLVE_BASE_DIR}/scripts/
@@ -329,6 +326,7 @@ process17() {
     # Extract panel API library
     create_directory ${DEB_DIR}/usr/lib
     extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libDaVinciPanelAPI.so
+    extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libFairlightPanelAPI.so
 
     # Create symlinks
     create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
